## django-plugins-bihealth

This is a fork of [django-plugins 0.3.0](https://github.com/krischer/django-plugins/releases/tag/0.3.0) which aims at modifying the package to work with Django v3.1+.

Contains our tweaks along with merges from forks by [Itxaka](https://github.com/Itxaka/) and [maxen-technology](https://github.com/maxen-technology/).

We aim to support modern (aka non-EOL) Python v3 versions and Django 3.x and onwards.
